@@ -20,6 +20,19 @@ import java.util.List;
  */
 public interface ValueProvider {
 
-    /** Gets value. */
+    /** Gets values. */
     List<String> getValues(String attributeName) throws ValueStorageException;
+
+    /**
+     * Sets values
+     * @param attributeName - name
+     * @param values - values
+     * @throws ValueStorageException
+     */
+    void setValues(String attributeName, List<String> values) throws ValueStorageException;
+
+    /**
+     * @return whether this Value Provider intended to initialize values
+     */
+    boolean isSettable();
 }
